==> tuia-ecb-center-api-1.1.0.7-sources.jar: cn/com/duiba/tuia/ecb/center/mix/dto/MixSignInDto.java <==
package cn.com.duiba.tuia.ecb.center.mix.dto;

import java.io.Serializable;
import java.util.List;

/**
 * MixSignInDto
 *
 * @author jiangshikui
 * @date 2020/1/9
 **/
public class MixSignInDto implements Serializable {


    private static final long serialVersionUID = 752457396306768267L;

    /**
     * 用户签到获取的金币
     */
    private Integer amount;

    private MixSignInRewardDto rewardDto;

    public Integer getCycle() {
        return cycle;
    }

    public void setCycle(Integer cycle) {
        this.cycle = cycle;
    }

    private List<MixSignInRecordDto> recordDtoList;

    /**
     * 是否可补签
     */
    private Boolean canReSignIn;

    private Integer cycle;

    public Integer getSevenDaysConfig() {
        return sevenDaysConfig;
    }

    public void setSevenDaysConfig(Integer sevenDaysConfig) {
        this.sevenDaysConfig = sevenDaysConfig;
    }

    private Integer incomeAmount;

    private Integer sevenDaysConfig;

    private Integer dailySignConfig;

    public Integer getDailySignConfig() {
        return dailySignConfig;
    }

    public void setDailySignConfig(Integer dailySignConfig) {
        this.dailySignConfig = dailySignConfig;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public MixSignInRewardDto getRewardDto() {
        return rewardDto;
    }

    public void setRewardDto(MixSignInRewardDto rewardDto) {
        this.rewardDto = rewardDto;
    }

    public List<MixSignInRecordDto> getRecordDtoList() {
        return recordDtoList;
    }

    public void setRecordDtoList(List<MixSignInRecordDto> recordDtoList) {
        this.recordDtoList = recordDtoList;
    }

    public Boolean getCanReSignIn() {
        return canReSignIn;
    }

    public void setCanReSignIn(Boolean canReSignIn) {
        this.canReSignIn = canReSignIn;
    }

    public Integer getIncomeAmount() {
        return incomeAmount;
    }

    public void setIncomeAmount(Integer incomeAmount) {
        this.incomeAmount = incomeAmount;
    }
}

==> tuia-ecb-center-api-1.1.1.12-sources.jar: cn/com/duiba/tuia/ecb/center/mix/dto/MixSignInDto.java <==
package cn.com.duiba.tuia.ecb.center.mix.dto;

import java.io.Serializable;
import java.util.List;

/**
 * MixSignInDto
 *
 * @author jiangshikui
 * @date 2020/1/9
 **/
public class MixSignInDto implements Serializable {
    private static final long serialVersionUID = 752457396306768267L;

    /**
     * 用户签到获取的金币
     */
    private Integer amount;

    private MixSignInRewardDto rewardDto;

    private List<MixSignInRecordDto> recordDtoList;

    /**
     * 是否可补签
     */
    private Boolean canReSignIn;

    private Integer cycle;

    /**
     * 翻倍倍数
     */
    private Integer doubleTimes;

    /**
     * 翻倍广告类型
     */
    private Integer doubleAdType;

    /**
     * 补签广告类型
     */
    private Integer reSignInAdType;

    /**
     * 翻倍激励id
     */
    private String rewardId;

    public Integer getSevenDaysConfig() {
        return sevenDaysConfig;
    }

    public void setSevenDaysConfig(Integer sevenDaysConfig) {
        this.sevenDaysConfig = sevenDaysConfig;
    }

    private Integer incomeAmount;

    private Integer sevenDaysConfig;

    private Integer dailySignConfig;

    public Integer getDailySignConfig() {
        return dailySignConfig;
    }

    public void setDailySignConfig(Integer dailySignConfig) {
        this.dailySignConfig = dailySignConfig;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public MixSignInRewardDto getRewardDto() {
        return rewardDto;
    }

    public void setRewardDto(MixSignInRewardDto rewardDto) {
        this.rewardDto = rewardDto;
    }

    public List<MixSignInRecordDto> getRecordDtoList() {
        return recordDtoList;
    }

    public void setRecordDtoList(List<MixSignInRecordDto> recordDtoList) {
        this.recordDtoList = recordDtoList;
    }

    public Boolean getCanReSignIn() {
        return canReSignIn;
    }

    public void setCanReSignIn(Boolean canReSignIn) {
        this.canReSignIn = canReSignIn;
    }

    public Integer getIncomeAmount() {
        return incomeAmount;
    }

    public void setIncomeAmount(Integer incomeAmount) {
        this.incomeAmount = incomeAmount;
    }

    public Integer getDoubleTimes() {
        return doubleTimes;
    }

    public void setDoubleTimes(Integer doubleTimes) {
        this.doubleTimes = doubleTimes;
    }

    public Integer getDoubleAdType() {
        return doubleAdType;
    }

    public void setDoubleAdType(Integer doubleAdType) {
        this.doubleAdType = doubleAdType;
    }

    public Integer getReSignInAdType() {
        return reSignInAdType;
    }

    public void setReSignInAdType(Integer reSignInAdType) {
        this.reSignInAdType = reSignInAdType;
    }

    public Integer getCycle() {
        return cycle;
    }

    public void setCycle(Integer cycle) {
        this.cycle = cycle;
    }

    public String getRewardId() {
        return rewardId;
    }

    public void setRewardId(String rewardId) {
        this.rewardId = rewardId;
    }
}
